@@ -33,31 +33,21 @@ from .user_utils import nocache
 CONFIG = PsiturkConfig()
 CONFIG.load_config()
 
-# Setup logging
-if 'ON_CLOUD' in os.environ:
-    LOG_FILE_PATH = None
-else:
-    LOG_FILE_PATH = os.path.join(os.getcwd(), CONFIG.get("Server Parameters",
-                                                         "logfile"))
-
 LOG_LEVELS = [logging.DEBUG, logging.INFO, logging.WARNING, logging.ERROR,
-              logging.CRITICAL]
+logging.CRITICAL]
 LOG_LEVEL = LOG_LEVELS[CONFIG.getint('Server Parameters', 'loglevel')]
-logging.basicConfig(filename=LOG_FILE_PATH, format='%(asctime)s %(message)s',
-                    level=LOG_LEVEL)
 
-
-# Status codes
+logfile = CONFIG.get("Server Parameters", "errorlog")
+if logfile != '-':
+    file_path = os.path.join(os.getcwd(), logfile)
+    logging.basicConfig(filename=file_path, format='%(asctime)s %(message)s',
+                        level=LOG_LEVEL)
 
 # Let's start
 # ===========
 
 app = Flask("Experiment_Server")
-
-# experiment server logging
-if 'gunicorn' in os.environ.get('SERVER_SOFTWARE', ''):
-    gunicorn_error_logger = logging.getLogger('gunicorn.error')
-    app.logger.handlers.extend(gunicorn_error_logger.handlers)
+app.logger.setLevel(LOG_LEVEL)
 
 # Set cache timeout to 10 seconds for static files
 app.config.update(SEND_FILE_MAX_AGE_DEFAULT=10)
